@@ -6,47 +6,21 @@ utils/colortype.py
 Created by FI$H 2000 on 2012-08-23.
 Copyright (c) 2012 Objects In Space And Time, LLC. All rights reserved.
 """
-
-import numpy
-#from os.path import join
+from __future__ import print_function
 from collections import namedtuple, defaultdict
 
-#from PIL import Image
-from math import floor
+from clu.constants.polyfills import numpy
+from clu.naming import split_abbreviations
+from instakit.exporting import Exporter
 
-#fract = lambda x: x * floor(x)
-#mix = lambda vX, vY, n: vX * (1.0-n) + (vY*n)
+exporter = Exporter(path=__file__)
+export = exporter.decorator()
 
-#@vectorize
-def fract(x):
-    return x * floor(x)
-
-#@vectorize
-def mix(vX, vY, n):
-    return vX * (1.0-n) + (vY*n)
-
-def split_abbreviations(s):
-    """ If you find this function inscrutable,
-        have a look here: https://gist.github.com/4027079 """
-    abbreviations = []
-    current_token = ''
-    for char in s:
-        if current_token is '':
-            current_token += char
-        elif char.islower():
-            current_token += char
-        else:
-            abbreviations.append(str(current_token))
-            current_token = ''
-            current_token += char
-    if current_token is not '':
-        abbreviations.append(str(current_token))
-    return abbreviations
-
-color_types = defaultdict(lambda: {})
+color_types = defaultdict(dict)
 
 # hash_RGB = lambda rgb: (rgb[0]*256)**2 + (rgb[1]*256) + rgb[2]
 
+@export
 def ColorType(name, *args, **kwargs):
     global color_types
     dtype = numpy.dtype(kwargs.pop('dtype', numpy.uint8))
@@ -78,8 +52,8 @@ def ColorType(name, *args, **kwargs):
                     return False
                 return all([self[i] == other[i] for i in range(len(self))])
             
-            def __unicode__(self):
-                return unicode(repr(self))
+            def __str__(self):
+                return str(repr(self))
             
             def composite(self):
                 return numpy.dtype([
@@ -90,3 +64,17 @@ def ColorType(name, *args, **kwargs):
         color_types[dtype.name][name] = Color
     return color_types[dtype.name][name]
 
+export(color_types,     name='color_types')
+
+# Assign the modules’ `__all__` and `__dir__` using the exporter:
+__all__, __dir__ = exporter.all_and_dir()
+
+def test():
+    assert split_abbreviations('RGB') == ('R', 'G', 'B')
+    assert split_abbreviations('CMYK') == ('C', 'M', 'Y', 'K')
+    assert split_abbreviations('YCbCr') == ('Y', 'Cb', 'Cr')
+    assert split_abbreviations('sRGB') == ('R', 'G', 'B')
+    assert split_abbreviations('XYZ') == ('X', 'Y', 'Z')
+
+if __name__ == '__main__':
+    test()
\ No newline at end of file
