@@ -8,7 +8,8 @@ Copyright (c) 2012 Objects In Space And Time, LLC. All rights reserved.
 """
 from __future__ import print_function
 
-import numpy, imread
+import numpy
+import imread
 from os.path import join
 from collections import defaultdict
 
@@ -66,9 +67,9 @@ class RGBTable(defaultdict):
         where = numpy.where(
             self.identity[:,:] == hash(color))
         print("WHERE:")
-        print(len(zip(*where)))
+        print(len(tuple(zip(*where))))
         try:
-            return zip(*where)[0]
+            return tuple(zip(*where))[0]
         except IndexError:
             return []
     
@@ -87,7 +88,6 @@ class RGBTable(defaultdict):
             data = self.identity
         return (channel/255.0 for channel in self.color_at(x, y, data=data))
 
-
 class LUT(RGBTable):
     
     def __init__(self, name='identity'):
@@ -101,7 +101,6 @@ class LUT(RGBTable):
         return imread.imread(
             static.path(join('lut', '%s.png' % name)))
 
-
 def main():
 
     RGB = ColorType('RGB')
@@ -121,7 +120,7 @@ def main():
     print(int(RGB(55,66,77)))
     print(numpy.any(identity.identity[:,:] == int(RGB(11,44,99))))
     print(numpy.max(identity.identity))
-    print(RGB(111, 222, 11).dtype_composite)
+    print(RGB(111, 222, 11).composite)
     
     print("")
     print(identity[RGB(146,146,36)])
@@ -133,7 +132,6 @@ def main():
     print(amatorka[RGB(146,146,36)])
     print(identity[RGB(22,33,44)])
     print(identity[RGB(255, 25, 25)])
-    
 
 def blurthday():
     
@@ -160,7 +158,6 @@ def blurthday():
     print(im1)
     print(im2)
 
-
 def old_maid():
     pass
     #global __multipons__
@@ -200,8 +197,6 @@ def old_main():
     #print(im_identity)
     print("")
     
-    
-    
     print("THE END: %s" % bool(im_old_identity.shape == im_identity.shape))
     #print(im_old_identity == im_identity)
     
@@ -216,11 +211,5 @@ def old_main():
     pil_im_identity.save('/tmp/im_identity.jpg',
         format="JPEG")
 
-
-
-
 if __name__ == '__main__':
-    main()
-
-
-
+    main()
\ No newline at end of file
